@@ -164,8 +164,7 @@ class ReplaceMatcher:
     def _fix_alignment_multiple_whitespaces(alignments):
         return [int(a / 2) for a in alignments]
 
-    @staticmethod
-    def _allow_multiple_whitespaces(patterns):
+    def _allow_multiple_whitespaces(self, patterns):
         """
         allow matching tokens separated by multiple whitespaces
         they may appear after normalizing nonstandard whitespaces
@@ -173,7 +172,7 @@ class ReplaceMatcher:
         pattern can be preceded and followed by whitespace tokens
         to keep preceded_by... with and succeeded_by... with match hooks working
         """
-        if True:
+        if self.allow_multiple_whitespaces:
             white_pattern = {"IS_SPACE": True, "OP": "?"}
             normalized_patterns = []
             for pattern in patterns:
